pub struct VirtualStoreArgs {
pub disable_global_virtual_store: bool,
pub enable_global_virtual_store: bool,
}Fields
disable_global_virtual_store: boolForce the shared global virtual store off for this invocation.
Packages are materialized inside the project’s virtual store
instead of symlinked from ~/.cache/aube/virtual-store/.
enable_global_virtual_store: boolForce the shared global virtual store on for this invocation.
Overrides CI’s default per-project materialization and the
disableGlobalVirtualStoreForPackages auto-disable heuristic.
Implementations
Sourceimpl VirtualStoreArgs
impl VirtualStoreArgs
pub fn flags(&self) -> GlobalVirtualStoreFlags
pub fn install_overrides(&self)